pub enum Units {
Amps(Option<DecimalPrefix>),
AmpHours(Option<DecimalPrefix>),
Hertz(Option<DecimalPrefix>),
Joules(Option<DecimalPrefix>),
Watts(Option<DecimalPrefix>),
Volts(Option<DecimalPrefix>),
Celsius(Option<DecimalPrefix>),
Number(Option<DecimalPrefix>),
Percent,
}Expand description
Units supported by NumericStateRecorder. The units! macro is recommended for construction.
Bytes and bit-rates are specifically not included yet because they invite the question of whether they should be restricted to binary prefixes. We’ll address that once we instrument a specific use case.
Variants
Amps(Option<DecimalPrefix>)
AmpHours(Option<DecimalPrefix>)
Hertz(Option<DecimalPrefix>)
Joules(Option<DecimalPrefix>)
Watts(Option<DecimalPrefix>)
Volts(Option<DecimalPrefix>)
Celsius(Option<DecimalPrefix>)
Number(Option<DecimalPrefix>)
Percent