pub struct EnumStateRecorder<T: RecordableEnum> { /* private fields */ }Expand description
Records time series data for an enum-valued state. This is best-suited for categorical observations, where the name of the state and not a numeric value will be most relevant for diagnostic and forensic purposes.
Implementations
Sourceimpl<T: RecordableEnum + 'static> EnumStateRecorder<T>
impl<T: RecordableEnum + 'static> EnumStateRecorder<T>
Sourcepub fn new(
name: String,
trace_category: &'static CStr,
options: RecorderOptions,
) -> Result<Self, StateRecorderError>
pub fn new( name: String, trace_category: &'static CStr, options: RecorderOptions, ) -> Result<Self, StateRecorderError>
Creates a new EnumStateRecorder with a given name.
See RecorderOptions for more details on options that can be specified.
Errors:
- StateRecorderError::DuplicateName:
metadata.nameis already in use by a StateRecorder associated withmanager. - StateRecorderError::IncompatibleString: Either
nameor the display name of a state cannot be converted to a CString. - StateRecorderError::InvalidOptions:
optionsis invalid for the given mode.
pub fn record(&mut self, state_enum: T)