pub struct NamedU64StateRecorder { /* private fields */ }Expand description
Records time series data for an named-u64 value state. This is best-suited for categorical observations, where the name of the state and not a numeric value will be most relevant for diagnostic and forensic purposes.
Implementations
Sourceimpl NamedU64StateRecorder
impl NamedU64StateRecorder
Sourcepub fn new(
name: String,
trace_category: &'static CStr,
state_names_map: HashMap<u64, String>,
options: RecorderOptions,
) -> Result<Self, StateRecorderError>
pub fn new( name: String, trace_category: &'static CStr, state_names_map: HashMap<u64, String>, options: RecorderOptions, ) -> Result<Self, StateRecorderError>
Creates a new NamedU64StateRecorder with a given name and a map of u64 to state names.
See RecorderOptions for more details on options that can be specified.
Errors:
- StateRecorderError::DuplicateName:
metadata.nameis already in use by a StateRecorder associated withmanager. - StateRecorderError::IncompatibleString: Either
nameor the display name of a state cannot be converted to a CString. - StateRecorderError::InvalidOptions:
optionsis invalid for the given mode.
pub fn record(&mut self, val: u64)