pub struct NumericStateRecorder<T: RecordableNumericType> { /* private fields */ }Implementations
Sourceimpl<T: RecordableNumericType> NumericStateRecorder<T>
impl<T: RecordableNumericType> NumericStateRecorder<T>
Sourcepub fn new(
name: String,
trace_category: &'static CStr,
units: Units,
range: Option<(T, T)>,
options: RecorderOptions,
) -> Result<Self, StateRecorderError>
pub fn new( name: String, trace_category: &'static CStr, units: Units, range: Option<(T, T)>, options: RecorderOptions, ) -> Result<Self, StateRecorderError>
Creates a new NumericStateRecorder.
See RecorderOptions for more details on options that can be specified.
Errors:
- StateRecorderError::DuplicateName:
metadata.nameis already in use by a StateRecorder associated withmanager. - StateRecorderError::IncompatibleString: Either
nameor the display name of a state cannot be converted to a CString. - StateRecorderError::InvalidOptions:
optionsis invalid for the given mode.
pub fn record(&mut self, state_value: T)