pub struct RecorderOptions {
pub lazy_record: bool,
pub capacity: usize,
pub manager: Option<Arc<Mutex<StateRecorderManager>>>,
pub persistence: Option<PersistenceOptions>,
}Expand description
Options for NumericStateRecorder and EnumStateRecorder
Fields
lazy_record: boolcapacity: usizeMaximum number of recorded values to store on a rolling basis.
manager: Option<Arc<Mutex<StateRecorderManager>>>Optional. If not set, the Recorder will be linked to this module’s singleton StateRecorderManager, which in turn corresponds to the singleton Inspector. If set, the manager supplied here will be used.
persistence: Option<PersistenceOptions>Trait Implementations
Sourceimpl Default for RecorderOptions
impl Default for RecorderOptions
Sourcefn default() -> RecorderOptions
fn default() -> RecorderOptions
Returns the “default value” for a type. Read more