pub trait RecordableNumericType:
Copy
+ Debug
+ Display
+ FromStr
+ Sized
+ Send
+ Sync
+ 'static {
type TraceType: ArgValue;
// Required methods
fn trace_value(&self) -> Self::TraceType;
fn record(&self, node: &Node, name: &str);
fn record_range(range: &(Self, Self), node: &Node);
}Expand description
To be recordable, a numeric type must, in essence, be able to widen into a trace-compatible type and an Inspect-compatible type. Users are not expected to implement this trait; this module implements it for common numeric types below.
Required Associated Types
Required Methods
fn trace_value(&self) -> Self::TraceType
fn record(&self, node: &Node, name: &str)
fn record_range(range: &(Self, Self), node: &Node)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.